@@ -6,7 +6,7 @@ def geojson_to_wkt(engine, gjson):
 
     # Build statement
     clean_gjson = str(gjson).replace("'", '"')
-    statement="SELECT ST_AsText(ST_GeomFromGeoJSON('" + clean_gjson + "'))"
+    statement="SELECT ST_AsText(ST_GeomFromGeoJSON('" + clean_gjson + "', 4326))"
 
     con=engine.connect()
 
