@@ -19,15 +19,8 @@ class TestGeospots(unittest.TestCase):
     def tearDown(self):
         """Tear down test fixtures, if any."""
 
-    def test_return_iso(self):
-        """Test that an isochrone within Indicium returns a polygon."""
-        test_this = return_iso(
-            api_key='5b3ce3597851110001cf62488b98dba3f6c7452b9d391c8306afa037',
-            locations=[[-48.51057, -27.57482]],
-            profile='driving-car',
-            range=[5]
-        )
-
+    def test_000_something(self):
+        """Test something."""
 
     def test_command_line_interface(self):
         """Test the CLI."""
